==> ph-xsds-xmldsig11-2.0.0-sources.jar: com/helger/xsds/xmldsig11/FieldIDType.java <==

package com.helger.xsds.xmldsig11;

import java.io.Serializable;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import com.helger.commons.annotation.ReturnsMutableCopy;
import com.helger.commons.equals.EqualsHelper;
import com.helger.commons.hashcode.HashCodeGenerator;
import com.helger.commons.string.ToStringGenerator;
import org.w3c.dom.Element;


/**
 * <p>Java class for FieldIDType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FieldIDType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice&gt;
 *         &lt;element ref="{http://www.w3.org/2009/xmldsig11#}Prime"/&gt;
 *         &lt;element ref="{http://www.w3.org/2009/xmldsig11#}TnB"/&gt;
 *         &lt;element ref="{http://www.w3.org/2009/xmldsig11#}PnB"/&gt;
 *         &lt;element ref="{http://www.w3.org/2009/xmldsig11#}GnB"/&gt;
 *         &lt;any processContents='lax' namespace='##other'/&gt;
 *       &lt;/choice&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * <p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-equalshashcode</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-tostring</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-cloneable</p>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FieldIDType", propOrder = {
    "prime",
    "tnB",
    "pnB",
    "gnB",
    "any"
})
@CodingStyleguideUnaware
public class FieldIDType implements Serializable, Cloneable
{

    @XmlElement(name = "Prime")
    private PrimeFieldParamsType prime;
    @XmlElement(name = "TnB")
    private TnBFieldParamsType tnB;
    @XmlElement(name = "PnB")
    private PnBFieldParamsType pnB;
    @XmlElement(name = "GnB")
    private CharTwoFieldParamsType gnB;
    @XmlAnyElement(lax = true)
    private Object any;

    /**
     * Gets the value of the prime property.
     * 
     * @return
     *     possible object is
     *     {@link PrimeFieldParamsType }
     *     
     */
    @Nullable
    public PrimeFieldParamsType getPrime() {
        return prime;
    }

    /**
     * Sets the value of the prime property.
     * 
     * @param value
     *     allowed object is
     *     {@link PrimeFieldParamsType }
     *     
     */
    public void setPrime(
        @Nullable
        PrimeFieldParamsType value) {
        this.prime = value;
    }

    /**
     * Gets the value of the tnB property.
     * 
     * @return
     *     possible object is
     *     {@link TnBFieldParamsType }
     *     
     */
    @Nullable
    public TnBFieldParamsType getTnB() {
        return tnB;
    }

    /**
     * Sets the value of the tnB property.
     * 
     * @param value
     *     allowed object is
     *     {@link TnBFieldParamsType }
     *     
     */
    public void setTnB(
        @Nullable
        TnBFieldParamsType value) {
        this.tnB = value;
    }

    /**
     * Gets the value of the pnB property.
     * 
     * @return
     *     possible object is
     *     {@link PnBFieldParamsType }
     *     
     */
    @Nullable
    public PnBFieldParamsType getPnB() {
        return pnB;
    }

    /**
     * Sets the value of the pnB property.
     * 
     * @param value
     *     allowed object is
     *     {@link PnBFieldParamsType }
     *     
     */
    public void setPnB(
        @Nullable
        PnBFieldParamsType value) {
        this.pnB = value;
    }

    /**
     * Gets the value of the gnB property.
     * 
     * @return
     *     possible object is
     *     {@link CharTwoFieldParamsType }
     *     
     */
    @Nullable
    public CharTwoFieldParamsType getGnB() {
        return gnB;
    }

    /**
     * Sets the value of the gnB property.
     * 
     * @param value
     *     allowed object is
     *     {@link CharTwoFieldParamsType }
     *     
     */
    public void setGnB(
        @Nullable
        CharTwoFieldParamsType value) {
        this.gnB = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * @return
     *     possible object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    @Nullable
    public Object getAny() {
        return any;
    }

    /**
     * Sets the value of the any property.
     * 
     * @param value
     *     allowed object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    public void setAny(
        @Nullable
        Object value) {
        this.any = value;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public boolean equals(final Object o) {
        if (o == this) {
            return true;
        }
        if ((o == null)||(!getClass().equals(o.getClass()))) {
            return false;
        }
        final FieldIDType rhs = ((FieldIDType) o);
        if (!EqualsHelper.equals(prime, rhs.prime)) {
            return false;
        }
        if (!EqualsHelper.equals(tnB, rhs.tnB)) {
            return false;
        }
        if (!EqualsHelper.equals(pnB, rhs.pnB)) {
            return false;
        }
        if (!EqualsHelper.equals(gnB, rhs.gnB)) {
            return false;
        }
        if (!EqualsHelper.equals(any, rhs.any)) {
            return false;
        }
        return true;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public int hashCode() {
        return new HashCodeGenerator(this).append(prime).append(tnB).append(pnB).append(gnB).append(any).getHashCode();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-tostring
     * 
     */
    @Override
    public String toString() {
        return new ToStringGenerator(this).append("prime", prime).append("tnB", tnB).append("pnB", pnB).append("gnB", gnB).append("any", any).getToString();
    }

    /**
     * This method clones all values from <code>this</code> to the passed object. All data in the parameter object is overwritten!Created by ph-jaxb22-plugin -Xph-cloneable
     * 
     * @param ret
     *     The target object to clone to. May not be <code>null</code>.
     */
    public void cloneTo(
        @Nonnull
        FieldIDType ret) {
        ret.any = any;
        ret.gnB = ((gnB == null)?null:gnB.clone());
        ret.pnB = ((pnB == null)?null:pnB.clone());
        ret.prime = ((prime == null)?null:prime.clone());
        ret.tnB = ((tnB == null)?null:tnB.clone());
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-cloneable
     * 
     * @return
     *     The cloned object. Never <code>null</code>.
     */
    @Nonnull
    @ReturnsMutableCopy
    @Override
    public FieldIDType clone() {
        FieldIDType ret = new FieldIDType();
        cloneTo(ret);
        return ret;
    }

}

==> ph-xsds-xmldsig11-2.2.6-sources.jar: com/helger/xsds/xmldsig11/FieldIDType.java <==

package com.helger.xsds.xmldsig11;

import java.io.Serializable;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import com.helger.commons.annotation.CodingStyleguideUnaware;
import com.helger.commons.annotation.ReturnsMutableCopy;
import com.helger.commons.equals.EqualsHelper;
import com.helger.commons.hashcode.HashCodeGenerator;
import com.helger.commons.lang.IExplicitlyCloneable;
import com.helger.commons.string.ToStringGenerator;
import org.w3c.dom.Element;


/**
 * <p>Java class for FieldIDType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FieldIDType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;choice&gt;
 *         &lt;element ref="{http://www.w3.org/2009/xmldsig11#}Prime"/&gt;
 *         &lt;element ref="{http://www.w3.org/2009/xmldsig11#}TnB"/&gt;
 *         &lt;element ref="{http://www.w3.org/2009/xmldsig11#}PnB"/&gt;
 *         &lt;element ref="{http://www.w3.org/2009/xmldsig11#}GnB"/&gt;
 *         &lt;any processContents='lax' namespace='##other'/&gt;
 *       &lt;/choice&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * <p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-equalshashcode</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-tostring</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-cloneable2</p>
 * <p>This class contains methods created by ph-jaxb22-plugin -Xph-value-extender</p>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FieldIDType", propOrder = {
    "prime",
    "tnB",
    "pnB",
    "gnB",
    "any"
})
@CodingStyleguideUnaware
public class FieldIDType implements Serializable, IExplicitlyCloneable
{

    @XmlElement(name = "Prime")
    private PrimeFieldParamsType prime;
    @XmlElement(name = "TnB")
    private TnBFieldParamsType tnB;
    @XmlElement(name = "PnB")
    private PnBFieldParamsType pnB;
    @XmlElement(name = "GnB")
    private CharTwoFieldParamsType gnB;
    @XmlAnyElement(lax = true)
    private Object any;

    /**
     * Default constructor<br>
     * Note: automatically created by ph-jaxb22-plugin -Xph-value-extender
     * 
     */
    public FieldIDType() {
    }

    /**
     * Gets the value of the prime property.
     * 
     * @return
     *     possible object is
     *     {@link PrimeFieldParamsType }
     *     
     */
    @Nullable
    public PrimeFieldParamsType getPrime() {
        return prime;
    }

    /**
     * Sets the value of the prime property.
     * 
     * @param value
     *     allowed object is
     *     {@link PrimeFieldParamsType }
     *     
     */
    public void setPrime(
        @Nullable
        PrimeFieldParamsType value) {
        this.prime = value;
    }

    /**
     * Gets the value of the tnB property.
     * 
     * @return
     *     possible object is
     *     {@link TnBFieldParamsType }
     *     
     */
    @Nullable
    public TnBFieldParamsType getTnB() {
        return tnB;
    }

    /**
     * Sets the value of the tnB property.
     * 
     * @param value
     *     allowed object is
     *     {@link TnBFieldParamsType }
     *     
     */
    public void setTnB(
        @Nullable
        TnBFieldParamsType value) {
        this.tnB = value;
    }

    /**
     * Gets the value of the pnB property.
     * 
     * @return
     *     possible object is
     *     {@link PnBFieldParamsType }
     *     
     */
    @Nullable
    public PnBFieldParamsType getPnB() {
        return pnB;
    }

    /**
     * Sets the value of the pnB property.
     * 
     * @param value
     *     allowed object is
     *     {@link PnBFieldParamsType }
     *     
     */
    public void setPnB(
        @Nullable
        PnBFieldParamsType value) {
        this.pnB = value;
    }

    /**
     * Gets the value of the gnB property.
     * 
     * @return
     *     possible object is
     *     {@link CharTwoFieldParamsType }
     *     
     */
    @Nullable
    public CharTwoFieldParamsType getGnB() {
        return gnB;
    }

    /**
     * Sets the value of the gnB property.
     * 
     * @param value
     *     allowed object is
     *     {@link CharTwoFieldParamsType }
     *     
     */
    public void setGnB(
        @Nullable
        CharTwoFieldParamsType value) {
        this.gnB = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * @return
     *     possible object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    @Nullable
    public Object getAny() {
        return any;
    }

    /**
     * Sets the value of the any property.
     * 
     * @param value
     *     allowed object is
     *     {@link Element }
     *     {@link Object }
     *     
     */
    public void setAny(
        @Nullable
        Object value) {
        this.any = value;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public boolean equals(final Object o) {
        if (o == this) {
            return true;
        }
        if ((o == null)||(!getClass().equals(o.getClass()))) {
            return false;
        }
        final FieldIDType rhs = ((FieldIDType) o);
        if (!EqualsHelper.equals(any, rhs.any)) {
            return false;
        }
        if (!EqualsHelper.equals(gnB, rhs.gnB)) {
            return false;
        }
        if (!EqualsHelper.equals(pnB, rhs.pnB)) {
            return false;
        }
        if (!EqualsHelper.equals(prime, rhs.prime)) {
            return false;
        }
        if (!EqualsHelper.equals(tnB, rhs.tnB)) {
            return false;
        }
        return true;
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-equalshashcode
     * 
     */
    @Override
    public int hashCode() {
        return new HashCodeGenerator(this).append(any).append(gnB).append(pnB).append(prime).append(tnB).getHashCode();
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-tostring
     * 
     */
    @Override
    public String toString() {
        return new ToStringGenerator(this).append("any", any).append("gnB", gnB).append("pnB", pnB).append("prime", prime).append("tnB", tnB).getToString();
    }

    /**
     * This method clones all values from <code>this</code> to the passed object. All data in the parameter object is overwritten!Created by ph-jaxb22-plugin -Xph-cloneable2
     * 
     * @param ret
     *     The target object to clone to. May not be <code>null</code>.
     */
    public void cloneTo(
        @Nonnull
        FieldIDType ret) {
        ret.any = any;
        ret.gnB = ((gnB == null)?null:gnB.clone());
        ret.pnB = ((pnB == null)?null:pnB.clone());
        ret.prime = ((prime == null)?null:prime.clone());
        ret.tnB = ((tnB == null)?null:tnB.clone());
    }

    /**
     * Created by ph-jaxb22-plugin -Xph-cloneable2
     * 
     * @return
     *     The cloned object. Never <code>null</code>.
     */
    @Nonnull
    @ReturnsMutableCopy
    @Override
    public FieldIDType clone() {
        FieldIDType ret = new FieldIDType();
        cloneTo(ret);
        return ret;
    }

}
